import org.junit.Assert;
import org.junit.Test;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import static org.junit.Assert.*;

public class MySetTest {

    @Test
    public void addTest() {
        MySet<Integer> ints = new MySet<Integer>();
        ints.add(1);
        ints.add(2);
        ints.add(3);
        Assert.assertTrue(ints.contains(2));
    }

    @Test
    public void addAllTest() {
        MySet<Integer> ints = new MySet<Integer>();

        List<Integer> toAdd = new ArrayList<Integer>();
        toAdd.add(1);
        toAdd.add(2);
        toAdd.add(3);

        boolean added = ints.addAll(toAdd);
        Assert.assertTrue(ints.containsAll(toAdd) && added);
    }

    @Test
    public void addTestDuplicatedValue() {
        MySet<Integer> ints = new MySet<Integer>();
        ints.add(1);
        ints.add(2);
        ints.add(3);

        boolean added = ints.add(3);

        Object[] expected = {1,2,3};
        Object[] actual = ints.toArray();

        Assert.assertFalse(added);
        Assert.assertTrue(Arrays.deepEquals(expected, actual));
    }
    @Test
    public void addAllTestDuplicatedValue() {
        MySet<Integer> ints = new MySet<Integer>();
        ints.add(1);
        ints.add(6);

        List<Integer> toAdd = new ArrayList<Integer>();
        toAdd.add(1);
        toAdd.add(2);
        toAdd.add(3);

        boolean added = ints.addAll(toAdd);
        Object[] expected = {1,6,2,3};
        Object[] actual = ints.toArray();

        Assert.assertTrue(Arrays.deepEquals(expected, actual) && added);
    }

    @Test
    public void clearTest() {
        MySet<Integer> ints = new MySet<Integer>();
        ints.add(1);
        ints.add(6);
        ints.clear();

        Object[] expected = {};
        Object[] actual = ints.toArray();

        Assert.assertTrue(Arrays.deepEquals(expected, actual));
    }

    @Test
    public void containsTest() {
        MySet<Integer> ints = new MySet<Integer>();
        ints.add(1);

        boolean expected = true;
        boolean actual = ints.contains(1);

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void containsAllTest() {
        MySet<Integer> ints = new MySet<Integer>();

        List<Integer> toAdd = new ArrayList<Integer>();
        toAdd.add(1);
        toAdd.add(2);
        toAdd.add(3);

        ints.addAll(toAdd);

        Assert.assertTrue(ints.containsAll(toAdd));
    }

    @Test
    public void sizeTest() {
        MySet<Integer> ints = new MySet<Integer>();
        ints.add(1);
        ints.add(2);
        ints.add(3);

        int expected = 3;
        int actual = ints.size();

        Assert.assertEquals(expected, actual);
    }

    @Test
    public void equalsTest() {
        MySet<Integer> ints = new MySet<Integer>();
        ints.add(1);
        ints.add(2);
        ints.add(3);

        MySet<Integer> ints2 = new MySet<Integer>();
        ints2.add(1);
        ints2.add(2);
        ints2.add(3);

        Assert.assertEquals(ints, ints2);

    }
}